aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJamieson Christian2003-05-25 01:42:53 +0000
committerJamieson Christian2003-05-25 01:42:53 +0000
commit45a2148d98e7aa13b1ad2bd61ec86ea908cc9f64 (patch)
tree5aefa0066ef8887d461e30fea4590ba17632ebe5
parent9ba6f4b43238f8f24f7fbbdf3545d16e9447553b (diff)
downloadscummvm-rg350-45a2148d98e7aa13b1ad2bd61ec86ea908cc9f64.tar.gz
scummvm-rg350-45a2148d98e7aa13b1ad2bd61ec86ea908cc9f64.tar.bz2
scummvm-rg350-45a2148d98e7aa13b1ad2bd61ec86ea908cc9f64.zip
Possible fix for [742962] MI1VGA - Crash at Scumm Bar.
Fixes End of Track that is rewritten from 'AD' resource. svn-id: r7922
-rw-r--r--scumm/resource.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/scumm/resource.cpp b/scumm/resource.cpp
index 56dc67ef40..46c0ddbd6c 100644
--- a/scumm/resource.cpp
+++ b/scumm/resource.cpp
@@ -1076,7 +1076,7 @@ int Scumm::readSoundResourceSmallHeader(int type, int idx) {
nukeResource(type, idx);
total_size = 8 + 16 + 14 + 8 + 7 + sizeof(OLD256_MIDI_HACK) + size;
if (!play_once)
- total_size += 20; // Up to 20 additional bytes are needed for the jump sysex
+ total_size += 24; // Up to 24 additional bytes are needed for the jump sysex
// Write the ADL header (see also above for more information)
ptr = createResource(type, idx, total_size);
@@ -1212,7 +1212,7 @@ int Scumm::readSoundResourceSmallHeader(int type, int idx) {
memcpy(ptr, "\x00\xf7", 2); ptr += 2; // sysex end marker
// Finally we reinsert the end of song sysex, just in case
- memcpy(ptr, "\x00\xff\x21", 3); ptr += 3;
+ memcpy(ptr, "\x00\xff\x21\x00\x00", 5); ptr += 5;
}
return 1;